﻿using System;
using Telerik.Windows.Controls;
using System.Windows;
using System.Windows.Data;
using System.Windows.Input;
using System.Windows.Controls;
using System.Collections.Generic;


namespace SilverlightApplication27
{
    /// <summary>
    /// Represents a column of data in a DataTable
    /// </summary>
    public class DataColumn
    {
        #region "Properties"

        /// <summary>
        /// Name of the column
        /// </summary>
        public string ColumnName { get; set; }

        /// <summary>
        /// Data type of the column
        /// </summary>
        public Type DataType { get; set; }

        /// <summary>
        /// Caption to be used in the column header
        /// </summary>
        public string Caption { get; set; }

        /// <summary>
        /// Allow the user to resize the column
        /// </summary>
        public bool AllowResize { get; set; }

        /// <summary>
        /// Allow the user to sort this column
        /// </summary>
        public bool AllowSort { get; set; }

        /// <summary>
        /// Allow the user to reorder this column
        /// </summary>
        public bool AllowReorder { get; set; }

        /// <summary>
        /// Column is read only
        /// </summary>
        public bool ReadOnly { get; set; }

        /// <summary>
        /// If column is hidden
        /// </summary>
        public bool IsHidden { get; set; }

        /// <summary>
        /// Set or Get the width of the column
        /// </summary>
        public double Width { get; set; }

        /// <summary>
        /// Name of group which belongs to
        /// </summary>
        public string GroupName { get; set; }

        /// <summary>
        /// Set or Get the width type of the column
        /// </summary>
        public GridViewLengthUnitType WidthType { get; set; }

        /// <summary>
        /// for row read-only
        /// </summary>
        public Binding IsReadOnlyBinding { get; set; }


        /// <summary>
        /// for command
        /// </summary>
        public ICommand Command { get; set; }

        /// <summary>
        /// for cell - style
        /// </summary>
        public StyleSelector CellStyleSelector { get; set; }

        /// <summary>
        /// for control style
        /// </summary>
        public Style ControlStyle { get; set; }

        /// <summary>
        /// buttons in a cell
        /// </summary>
        public List<Tuple<ICommand, object, Style>> BindableRadButtonValues { get; set; }

        public bool? ColumnVisible { get; set; }
        /// <summary>
        /// for which is need in rad grid ctrl
        /// </summary>
        public bool IsNotVisible { get; set; }

        /// <summary>
        /// DataFormatString
        /// </summary>
        public string DataFormatString { get; set; }

        public bool IsFilterable { get; set; }

        public bool IsGroupable { get; set; }
        #endregion

        #region "Methods"

        /// <summary>
        /// Constructor with a column name.
        /// The caption (header) will be the same.
        /// Defaults to "String" type
        /// </summary>
        /// <param name="columnName">Name of the column</param>
        public DataColumn(string columnName)
        {
            this.ColumnName = columnName;
            // Default values
            this.Caption = columnName; // By default it will be the same unless we change it
            this.AllowResize = true;
            this.AllowSort = true;
            this.AllowReorder = true;
            this.ReadOnly = false;
            this.DataType = typeof(String);
        }

        /// <summary>
        /// Constructor with a column name and a type.
        /// The caption (header) will be the same as the column name.
        /// </summary>
        /// <param name="columnName">Name of the column</param>
        /// <param name="columnType">Type of the column</param>
        public DataColumn(string columnName, Type columnType)
            : this(columnName)
        {
            this.DataType = columnType;
        }

        public DataColumn Clone()
        {
            DataColumn driver = MemberwiseClone() as DataColumn;
            return driver;
        }

        public string GroupNameAlign { get; set; }
        
        #endregion
    }
}