﻿#region Copyright PwC SDC 2012
//
// All rights are reserved. Reproduction or transmission in whole or in part, in
// any form or by any means, electronic, mechanical or otherwise, is prohibited
// without the prior written consent of the copyright owner.
// Created By: ulu001
// Created Date: 10 30 2012
// Modification history:
//
#endregion
using System;
using System.Windows;
using System.Windows.Input;
using System.Windows.Interactivity;


namespace SilverlightApplication27
{
    public class EventToCommand : EventToCommandBase<EventArgs>
    {

    }

    public abstract class EventToCommandBase<TEventArgs> : TriggerAction<FrameworkElement> where TEventArgs:EventArgs
    {
        public static readonly DependencyProperty CommandProperty = DependencyProperty.Register("Command"
                                                                                                , typeof(ICommand)
                                                                                                , typeof(EventToCommandBase<TEventArgs>)
                                                                                                , new PropertyMetadata(null, OnCommandPropertyChanged));
        public static readonly DependencyProperty CommandParameterProperty = DependencyProperty.Register("CommandParameter"
                                                                                                , typeof(object)
                                                                                                , typeof(EventToCommandBase<TEventArgs>)
                                                                                                , new PropertyMetadata(null, OnCommandParameterPropertyChanged));

        public ICommand Command
        {
            get
            {
                return (ICommand)base.GetValue(CommandProperty);
            }
            set
            {
                base.SetValue(CommandProperty, value);
            }
        }

        public object CommandParameter
        {
            get
            {
                return base.GetValue(CommandParameterProperty);
            }
            set
            {
                base.SetValue(CommandParameterProperty, value);
            }
        }

        static void OnCommandParameterPropertyChanged(DependencyObject dependObj, DependencyPropertyChangedEventArgs dependEvent)
        {
            var invokeCommand = dependObj as EventToCommand;
            if (invokeCommand != null)
            {
                invokeCommand.SetValue(CommandParameterProperty, dependEvent.NewValue);
            }
        }


        static void OnCommandPropertyChanged(DependencyObject dependObj, DependencyPropertyChangedEventArgs dependEvent)
        {
            var invokeCommand = dependObj as EventToCommand;
            if (invokeCommand != null)
            {
                invokeCommand.SetValue(CommandProperty, dependEvent.NewValue);
            }
        }

        #region <<Need to implementation base method>>
        protected override void Invoke(object parameter)
        {
            if (this.Command == null)
            {
                return;
            }

            var eventInfo = new EventInfo<TEventArgs>
            {
                EventArgs = parameter as TEventArgs,
                Sender = this.AssociatedObject,
            };

            if (this.Command.CanExecute(eventInfo))
            {
                this.Command.Execute(eventInfo);
            }
        }
        #endregion
       
    }
}
